"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.destination = void 0;
const tslib_1 = require("tslib");
const actions_core_1 = require("@segment/actions-core");
const shim_1 = require("@segment/browser-destination-runtime/shim");
const attach_1 = tslib_1.__importDefault(require("./attach"));
const presets = [
    {
        name: 'Attach Device',
        subscribe: "type = 'page'",
        partnerAction: 'attach',
        mapping: (0, actions_core_1.defaultValues)(attach_1.default.fields),
        type: 'automatic'
    }
];
exports.destination = {
    name: 'Rupt',
    slug: 'actions-rupt',
    mode: 'device',
    presets,
    settings: {
        client_id: {
            description: 'The API client id of your Rupt project.',
            label: 'Client ID',
            type: 'string',
            required: true
        },
        new_account_url: {
            description: 'A URL to redirect the user to if they want to stop account sharing and create a new account.',
            label: 'New Account URL',
            type: 'string',
            required: true
        },
        logout_url: {
            description: 'A URL to redirect the user to if they choose to logout or if they are removed by a verified owner.',
            label: 'Logout URL',
            type: 'string',
            required: false
        },
        success_url: {
            description: 'A URL to redirect the user to if they are successfully verified and are within the device limit.',
            label: 'Success URL',
            type: 'string',
            required: false
        },
        suspended_url: {
            description: 'A URL to redirect the user to if they are suspended.',
            label: 'Suspended URL',
            type: 'string',
            required: false
        }
    },
    initialize: async (_, deps) => {
        try {
            await deps.loadScript('https://cdn.rupt.dev/js/rupt.js');
            await deps.resolveWhen(() => Object.prototype.hasOwnProperty.call(window, 'Rupt'), 500);
            return window.Rupt;
        }
        catch (error) {
            throw new Error('Failed to load Rupt. ' + error);
        }
    },
    actions: {
        attach: attach_1.default
    }
};
exports.default = (0, shim_1.browserDestination)(exports.destination);
//# sourceMappingURL=index.js.map